==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebColumnMovingEndEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEndEventArgsDetailDescription } from "./WebColumnMovingEndEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnMovingEndEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnMovingEndEventArgsDetailDescriptionMetadata, _super);
    function WebColumnMovingEndEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnMovingEndEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnMovingEndEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingEndEventArgsDetailDescriptionMetadata.c(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnMovingEndEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Source", "ExportedType:WebColumn");
        a.item("Target", "ExportedType:WebColumn");
        a.item("Cancel", "Boolean");
    };
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnMovingEndEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebColumnMovingEndEventArgsDetail", function () { return new WebColumnMovingEndEventArgsDetailDescription(); });
        a.z("WebColumnMovingEndEventArgsDetail", WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.$t = markType(WebColumnMovingEndEventArgsDetailDescriptionMetadata, 'WebColumnMovingEndEventArgsDetailDescriptionMetadata');
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingEndEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnMovingEndEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnMovingEndEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEndEventArgsDetailDescription } from "./WebColumnMovingEndEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnMovingEndEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnMovingEndEventArgsDetailDescriptionMetadata, _super);
    function WebColumnMovingEndEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnMovingEndEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnMovingEndEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingEndEventArgsDetailDescriptionMetadata.c(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnMovingEndEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Source", "ExportedType:WebColumn");
        a.item("Target", "ExportedType:WebColumn");
        a.item("Cancel", "Boolean");
    };
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnMovingEndEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebColumnMovingEndEventArgsDetail", function () { return new WebColumnMovingEndEventArgsDetailDescription(); });
        a.ab("WebColumnMovingEndEventArgsDetail", WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.$t = markType(WebColumnMovingEndEventArgsDetailDescriptionMetadata, 'WebColumnMovingEndEventArgsDetailDescriptionMetadata');
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingEndEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnMovingEndEventArgsDetailDescriptionMetadata };
